import { ICountry, IState, ICity } from 'country-state-city';
import { useLayoutEffect } from 'react';

declare function useCountries(): {
    countries: ICountry[];
    getStatesOfCountry: (countryCode: string) => IState[];
    getCitiesOfState: (countryCode: string, stateCode: string) => ICity[];
};

/**
 * On the server, React emits a warning when calling `useLayoutEffect`.
 * This is because neither `useLayoutEffect` nor `useEffect` run on the server.
 * We use this safe version which suppresses the warning by replacing it with a noop on the server.
 *
 * See: https://reactjs.org/docs/hooks-reference.html#uselayouteffect
 */
declare const useIsomorphicLayoutEffect: typeof useLayoutEffect;

type ModalType = string;
interface UseModal<T> {
    actions: {
        onClose: () => void;
        onOpen: (data?: T) => void;
    };
    isOpen: boolean;
    data?: T;
}
declare function useModalActions<T>(type: ModalType): UseModal<T>['actions'];
declare function useModalOpen<T>(type: ModalType): UseModal<T>['isOpen'];
declare function useModalData<T>(type: ModalType): T | undefined;
declare function switchModal<T>(currentType: ModalType, targetType: ModalType): void;

declare function useMounted(): boolean;

declare function useOrigin(): string;

declare function usePrevious<T>(value: T): T | undefined;

export { UseModal, switchModal, useCountries, useIsomorphicLayoutEffect, useModalActions, useModalData, useModalOpen, useMounted, useOrigin, usePrevious };
