'use strict';

var countryStateCity = require('country-state-city');
var react = require('react');
var zustand = require('zustand');

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
function useCountries() {
  const countries = react.useMemo(
    () => countryStateCity.Country.getAllCountries().map((country) => __spreadProps(__spreadValues({}, country), {
      phonecode: country.phonecode.startsWith("+") ? country.phonecode : `+${country.phonecode}`
    })),
    []
  );
  const getStatesOfCountry = (countryCode) => {
    return countryStateCity.State.getStatesOfCountry(countryCode);
  };
  const getCitiesOfState = (countryCode, stateCode) => {
    return countryStateCity.City.getCitiesOfState(countryCode, stateCode);
  };
  return {
    countries,
    getCitiesOfState,
    getStatesOfCountry
  };
}
var useIsomorphicLayoutEffect = typeof window !== "undefined" ? react.useLayoutEffect : () => {
};
var stores = /* @__PURE__ */ new Map();
function getModalStore(type) {
  return stores.get(type);
}
function setModalStore(type, store) {
  stores.set(type, store);
  return store;
}
function createModalStore() {
  return zustand.create((set) => ({
    actions: {
      onClose: () => {
        set({ isOpen: false });
      },
      onOpen: (data) => {
        set({ data, isOpen: true });
      }
    },
    data: void 0,
    isOpen: false
  }));
}
function useModalActions(type) {
  let store = getModalStore(type);
  if (!store) {
    store = setModalStore(type, createModalStore());
  }
  return store((state) => state.actions);
}
function useModalOpen(type) {
  let store = getModalStore(type);
  if (!store) {
    store = setModalStore(type, createModalStore());
  }
  return store((state) => state.isOpen);
}
function useModalData(type) {
  let store = getModalStore(type);
  if (!store) {
    store = setModalStore(type, createModalStore());
  }
  return store((state) => state.data);
}
function switchModal(currentType, targetType) {
  const currentStore = getModalStore(currentType);
  const targetStore = getModalStore(targetType);
  if (currentStore && targetStore) {
    currentStore.setState({ isOpen: false });
    targetStore.setState({ isOpen: true });
  } else if (!targetStore) {
    const newStore = createModalStore();
    setModalStore(targetType, newStore);
    newStore.setState({ isOpen: true });
  }
}
function useMounted() {
  const [mounted, setMounted] = react.useState(false);
  react.useEffect(() => {
    setMounted(true);
  }, []);
  return mounted;
}

// src/use-origin.ts
function useOrigin() {
  const mounted = useMounted();
  if (!mounted) {
    return "";
  }
  return typeof window !== "undefined" ? window.location.origin || "" : "";
}
function usePrevious(value) {
  const ref = react.useRef(value);
  react.useEffect(() => {
    ref.current = value;
  }, [value]);
  return ref.current;
}

exports.switchModal = switchModal;
exports.useCountries = useCountries;
exports.useIsomorphicLayoutEffect = useIsomorphicLayoutEffect;
exports.useModalActions = useModalActions;
exports.useModalData = useModalData;
exports.useModalOpen = useModalOpen;
exports.useMounted = useMounted;
exports.useOrigin = useOrigin;
exports.usePrevious = usePrevious;
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.js.map